==> composite_reference-2.2.0.tar.gz: composite_reference/CHANGELOG.md <==
# Changelog

## [2.2.0](https://github.com/openeuropa/composite_reference/tree/2.2.0) (2023-02-22)
[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.1.1...2.2.0)

**Merged pull requests:**

- EWPP-2991: Drupal 10 compatibility. [\#23](https://github.com/openeuropa/composite_reference/pull/23) ([brummbar](https://github.com/brummbar))
- EWPP-2885: Update to PHP 8.1. [\#22](https://github.com/openeuropa/composite_reference/pull/22) ([22Alexandra](https://github.com/22Alexandra))

## [2.1.1](https://github.com/openeuropa/composite_reference/tree/2.1.1) (2022-12-02)
[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.1.0...2.1.1)

**Merged pull requests:**

- EWPP-2817: Ensure query access check not used in getReferencingEntities. [\#20](https://github.com/openeuropa/composite_reference/pull/20) ([nagyad](https://github.com/nagyad))

## [2.1.0](https://github.com/openeuropa/composite_reference/tree/2.1.0) (2022-02-03)
[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.0.0...2.1.0)

**Merged pull requests:**

- EWPP-1913: Update to PHP8 and Composer v2. [\#17](https://github.com/openeuropa/composite_reference/pull/17) ([22Alexandra](https://github.com/22Alexandra))
- EWPP-1858: Do not query revisions on non-revisionable entity types. [\#16](https://github.com/openeuropa/composite_reference/pull/16) ([upchuk](https://github.com/upchuk))
- EWPP-1706: Drupal 9 compatibility. [\#15](https://github.com/openeuropa/composite_reference/pull/15) ([upchuk](https://github.com/upchuk))

## [2.0.0](https://github.com/openeuropa/composite_reference/tree/2.0.0) (2021-10-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0...2.0.0)

- Promote release 8.x-1.0 to 2.0.0.

## [8.x-1.0](https://github.com/openeuropa/composite_reference/tree/8.x-1.0) (2021-10-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0-alpha2...8.x-1.0)

**Merged pull requests:**

- Prepare release 8.x-1.0. [\#12](https://github.com/openeuropa/composite_reference/pull/12) ([imanoleguskiza](https://github.com/imanoleguskiza))
- EWPP-788: Implement support for entities referenced in old revisions. [\#11](https://github.com/openeuropa/composite_reference/pull/11) ([nagyad](https://github.com/nagyad))
- EWPP-721: Update xdebug configuration. [\#10](https://github.com/openeuropa/composite_reference/pull/10) ([22Alexandra](https://github.com/22Alexandra))
- EWPP-529: Replace drupal scaffolding library. [\#9](https://github.com/openeuropa/composite_reference/pull/9) ([sergepavle](https://github.com/sergepavle))
- EWPP-516: Update docker images. [\#8](https://github.com/openeuropa/composite_reference/pull/8) ([22Alexandra](https://github.com/22Alexandra))

## [8.x-1.0-alpha2](https://github.com/openeuropa/composite_reference/tree/8.x-1.0-alpha2) (2020-06-16)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0-alpha1...8.x-1.0-alpha2)

**Merged pull requests:**

- Prepare alpha2 release. [\#7](https://github.com/openeuropa/composite_reference/pull/7) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Fix variable name bug in determining the referencing fields. [\#6](https://github.com/openeuropa/composite_reference/pull/6) ([nagyad](https://github.com/nagyad))

## [8.x-1.0-alpha1](https://github.com/openeuropa/composite_reference/tree/8.x-1.0-alpha1) (2020-06-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/e8566dfe7357f56be3a9c90f7d68c76a1883e823...8.x-1.0-alpha1)

**Merged pull requests:**

- Update release name. [\#5](https://github.com/openeuropa/composite_reference/pull/5) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Use uuid to exclude self when deleting references. [\#4](https://github.com/openeuropa/composite_reference/pull/4) ([imanoleguskiza](https://github.com/imanoleguskiza))
- Prepare alpha1 release. [\#3](https://github.com/openeuropa/composite_reference/pull/3) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Add core functionality. [\#2](https://github.com/openeuropa/composite_reference/pull/2) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Initial scaffolding. [\#1](https://github.com/openeuropa/composite_reference/pull/1) ([imanoleguskiza](https://github.com/imanoleguskiza))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> composite_reference-2.3.1.tar.gz: composite_reference/CHANGELOG.md <==
# Changelog

## [2.3.0](https://github.com/openeuropa/composite_reference/tree/2.3.0) (2024-02-16)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.2.0...2.3.0)

**Merged pull requests:**

- EWPP-3964: Drop D9 and add D10.2 and php8.2 to matrix. [\#25](https://github.com/openeuropa/composite_reference/pull/25) ([nagyad](https://github.com/nagyad))

## [2.2.0](https://github.com/openeuropa/composite_reference/tree/2.2.0) (2023-02-22)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.1.1...2.2.0)

**Merged pull requests:**

- Prepare changelog for release 2.2.0. [\#24](https://github.com/openeuropa/composite_reference/pull/24) ([brummbar](https://github.com/brummbar))
- EWPP-2991: Drupal 10 compatibility. [\#23](https://github.com/openeuropa/composite_reference/pull/23) ([brummbar](https://github.com/brummbar))
- EWPP-2885: Update to PHP 8.1. [\#22](https://github.com/openeuropa/composite_reference/pull/22) ([22Alexandra](https://github.com/22Alexandra))

## [2.1.1](https://github.com/openeuropa/composite_reference/tree/2.1.1) (2022-12-02)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/2.1.0...2.1.1)

**Merged pull requests:**

- Release-2.1.1: Update changelog. [\#21](https://github.com/openeuropa/composite_reference/pull/21) ([nagyad](https://github.com/nagyad))
- EWPP-2817: Ensure query access check not used in getReferencingEntities. [\#20](https://github.com/openeuropa/composite_reference/pull/20) ([nagyad](https://github.com/nagyad))

## [2.1.0](https://github.com/openeuropa/composite_reference/tree/2.1.0) (2022-02-03)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0-alpha3...2.1.0)

**Merged pull requests:**

- EWPP-1913: Update to PHP8 and Composer v2. [\#17](https://github.com/openeuropa/composite_reference/pull/17) ([22Alexandra](https://github.com/22Alexandra))
- EWPP-1858: Do not query revisions on non-revisionable entity types. [\#16](https://github.com/openeuropa/composite_reference/pull/16) ([upchuk](https://github.com/upchuk))
- EWPP-1706: Drupal 9 compatibility. [\#15](https://github.com/openeuropa/composite_reference/pull/15) ([upchuk](https://github.com/upchuk))

## [2.0.0](https://github.com/openeuropa/composite_reference/tree/2.0.0) (2021-10-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0...2.0.0)

- Promote release 8.x-1.0 to 2.0.0.

## [8.x-1.0](https://github.com/openeuropa/composite_reference/tree/8.x-1.0) (2021-10-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0-alpha2...8.x-1.0)

**Merged pull requests:**

- Prepare release 8.x-1.0. [\#12](https://github.com/openeuropa/composite_reference/pull/12) ([imanoleguskiza](https://github.com/imanoleguskiza))
- EWPP-788: Implement support for entities referenced in old revisions. [\#11](https://github.com/openeuropa/composite_reference/pull/11) ([nagyad](https://github.com/nagyad))
- EWPP-721: Update xdebug configuration. [\#10](https://github.com/openeuropa/composite_reference/pull/10) ([22Alexandra](https://github.com/22Alexandra))
- EWPP-529: Replace drupal scaffolding library. [\#9](https://github.com/openeuropa/composite_reference/pull/9) ([sergepavle](https://github.com/sergepavle))
- EWPP-516: Update docker images. [\#8](https://github.com/openeuropa/composite_reference/pull/8) ([22Alexandra](https://github.com/22Alexandra))

## [8.x-1.0-alpha2](https://github.com/openeuropa/composite_reference/tree/8.x-1.0-alpha2) (2020-06-16)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/8.x-1.0-alpha1...8.x-1.0-alpha2)

**Merged pull requests:**

- Prepare alpha2 release. [\#7](https://github.com/openeuropa/composite_reference/pull/7) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Fix variable name bug in determining the referencing fields. [\#6](https://github.com/openeuropa/composite_reference/pull/6) ([nagyad](https://github.com/nagyad))

## [8.x-1.0-alpha1](https://github.com/openeuropa/composite_reference/tree/8.x-1.0-alpha1) (2020-06-15)

[Full Changelog](https://github.com/openeuropa/composite_reference/compare/e8566dfe7357f56be3a9c90f7d68c76a1883e823...8.x-1.0-alpha1)

**Merged pull requests:**

- Update release name. [\#5](https://github.com/openeuropa/composite_reference/pull/5) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Use uuid to exclude self when deleting references. [\#4](https://github.com/openeuropa/composite_reference/pull/4) ([imanoleguskiza](https://github.com/imanoleguskiza))
- Prepare alpha1 release. [\#3](https://github.com/openeuropa/composite_reference/pull/3) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Add core functionality. [\#2](https://github.com/openeuropa/composite_reference/pull/2) ([imanoleguskiza](https://github.com/imanoleguskiza))
- OPENEUROPA-3135: Initial scaffolding. [\#1](https://github.com/openeuropa/composite_reference/pull/1) ([imanoleguskiza](https://github.com/imanoleguskiza))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
